from AbstractHeader import AbstractHeader

##
# @brief Ancillary Text Header class.
# @details Can attach useful but optional ancillary text
# @author Miguel Dominguez
# @date 2016
class AncillaryTextHeader(AbstractHeader):

   ##
   # @fn headerIndex
   # @brief Return the header index of an Ancillary Text Header.
   # @param[out] output Always 6
   @staticmethod
   def headerIndex():
      return 6

   ##
   # @fn getHeader
   # @brief Extract header data from input bytes.
   # @details This function extracts header data from a buffer and stores it
   # within the object.  A version of the data buffer with the header bytes
   # chomped off is returned
   # @param[in] Raw unsigned bytes that contain the header at the beginning
   # @param[out] The input buffer with header bytes removed
   def getHeader(self,data):
      self.headerRecordLength = (data[1] << self.BYTE_SHIFT) | data[2]
      self.ancillaryText = "".join(map(chr,data[3:self.headerRecordLength]))
      return data[self.headerRecordLength:len(data)]

   ##
   # @fn __str__
   # @brief Returns formatted header information as a string
   # @param[out] str Header information as a string
   def __str__(self):
      output = "Ancillary Text Header\n"
      output += "Header Record Length: {0}\n".format(self.headerRecordLength)
      output += "Ancillary Text: {0}\n".format(self.ancillaryText)
      return output
