from AbstractHeader import AbstractHeader

##
# @brief Key header class.
# @details File encoding information for images
# @author Miguel Dominguez
# @date 2016
# @warning This type of header is actually not completely specified by the LRIT
# spec. It has to exist, but is not currently used
class KeyHeader(AbstractHeader):

   ##
   # @fn headerIndex
   # @brief Return the header index of an Annotation Header.
   # @param[out] output Always 7
   @staticmethod
   def headerIndex():
      return 7

   ##
   # @fn getHeader
   # @brief Extract header data from input bytes.
   # @details This function extracts header data from a buffer and stores it
   # within the object.  A version of the data buffer with the header bytes
   # chomped off is returned
   # @param[in] Raw unsigned bytes that contain the header at the beginning
   # @param[out] The input buffer with header bytes removed
   def getHeader(self,data):
      self.headerRecordLength = (data[1] << self.BYTE_SHIFT) | data[2]
      return data[self.headerRecordLength:len(data)]

   ##
   # @fn __str__
   # @brief Returns formatted header information as a string
   # @param[out] str Header information as a string
   def __str__(self):
      output = "Key Header\n"
      output += "Header Record Length: {0}\n".format(self.headerRecordLength)
      return output
