from AbstractHeader import AbstractHeader

##
# @brief Primary header class.
# @details Identifies some basic information about the file that the file
# builder can make use of.
# @author Miguel Dominguez
# @date 2016
# @warning THIS HEADER MUST COME FIRST IN A SEQUENCE OF HEADERS
class PrimaryHeader(AbstractHeader):
   
   EMWIN_FILE_TYPE_CODE = 214
   
   ##
   # @fn headerIndex
   # @brief Return the header index of an Annotation Header.
   # @param[out] output Always 0
   @staticmethod
   def headerIndex():
      return 0

   ##
   # @fn getHeader
   # @brief Extract header data from input bytes.
   # @details This function extracts header data from a buffer and stores it
   # within the object.  A version of the data buffer with the header bytes
   # chomped off is returned
   # @param[in] Raw unsigned bytes that contain the header at the beginning
   # @param[out] The input buffer with header bytes removed
   def getHeader(self,data):
      self.headerRecordLength = (data[1] << self.BYTE_SHIFT) | data[2]
      self.fileTypeCode = data[3]
      self.allHeadersLength = 0
      for i in range(4):
         self.allHeadersLength <<= self.BYTE_SHIFT
         self.allHeadersLength |= (data[4 + i] &0xFF)
      self.fileLengthBits = 0
      for i in range(8):
         self.fileLengthBits <<= self.BYTE_SHIFT
         self.fileLengthBits |= data[8 + i]
      return data[self.headerRecordLength:len(data)]

   ##
   # @fn __str__
   # @brief Returns formatted header information as a string
   # @param[out] str Header information as a string
   def __str__(self):
      output = "Primary Header\n"
      output += "Header Record Length: {0}\n".format(self.headerRecordLength)
      output += "Filetype Code: {0}\n".format(self.fileTypeCode)
      output += "Length of all Headers: {0}\n".format(self.allHeadersLength)
      output += "File Length in Bits: {0}\n".format(self.fileLengthBits)
      return output
