#!/usr/bin/env python
# -*- coding: utf-8 -*-
# 
# Copyright 2016 <+YOU OR YOUR COMPANY+>.
# 
# This is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
# 
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this software; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
# 

from gnuradio import gr, gr_unittest
from gnuradio import blocks
from block_interleaver import block_interleaver
import numpy as np

class qa_block_interleaver (gr_unittest.TestCase):

    def setUp (self):
        self.tb = gr.top_block ()

    def tearDown (self):
        self.tb = None

    def test_001 (self):
        """Test interleaving"""
        # test using ramp to test passed data
        tb = self.tb

        N, rows = 20, 4
        data = range(N)
        src = blocks.vector_source_i(data)
        but = block_interleaver(rows, N)
        snk = blocks.vector_sink_i()
        
        tb.connect(src, but, snk)
        tb.run()
        tb.wait()
        
        rcv = snk.data()
        ref = np.reshape(data, (rows, N / rows)).T.flatten().tolist()
        self.assertEquals(rcv, ref)
        
    def test_002 (self):
        """Test shift (swap)"""
        
        N = 20
        data = range(N)
        src = blocks.vector_source_i(data)
        but = block_interleaver(2, 2, 1)        # swap every other
        snk = blocks.vector_sink_i()
        
        tb.connect(src, but, snk)
        tb.run()
        tb.wait()
        
        rcv = snk.data()
        ref = np.roll(np.reshape(data, (-1, 2)), 1, 1).flatten().tolist()
        self.assertEquals(rcv, ref)
        
        
